DaCy
================================

.. image:: https://img.shields.io/github/stars/centre-for-humanities-computing/DaCy.svg?style=social&label=Star&maxAge=2592000
   :target: https://github.com/centre-for-humanities-computing/DaCy

DaCy is a Danish text processing pipeline built using SpaCy. At the time of writing,
it has achieved State-of-the-Art performance on part-of-speech (POS) tagging, 
named-entity recognition (NER) and Dependency parsing for Danish. For an continually
updated benchmark check out section on
`state-of-art <https://centre-for-humanities-computing.github.io/DaCy/docs/_build/html/performance.general.html#state-of-the-art>`__.

This website contains the documentation for DaCy as well as an introduction to how to
get started using DaCy and its various features.

Where to ask questions?
^^^^^^^^^^^^^^^^^^^^^^^^

To ask report issues or request features, please use the
`GitHub Issue Tracker <https://github.com/centre-for-humanities-computing/DaCy/issues>`__.
Questions related to SpaCy are kindly referred to the SpaCy GitHub or forum. Otherwise,
please use the discussion Forums.

+------------------------------+-------------------------+
| Type                         |                         |
+------------------------------+-------------------------+
| **Bug Reports**              | `GitHub Issue Tracker`_ |
+------------------------------+-------------------------+
| **Feature Requests & Ideas** | `GitHub Issue Tracker`_ |
+------------------------------+-------------------------+
| **Usage Questions**          | `GitHub Discussions`_   |
+------------------------------+-------------------------+
| **General Discussion**       | `GitHub Discussions`_   |
+------------------------------+-------------------------+


.. _GitHub Issue Tracker: https://github.com/centre-for-humanities-computing/DaCy/issues
.. _GitHub Discussions: https://github.com/centre-for-humanities-computing/DaCy/discussions

Acknowledgements
^^^^^^^^^^^^^^^^^^^^

DaCy is a result of great open-source software and contributors. It wouldn't have been
possible without the work by the SpaCy team which developed and integrated the software.
Huggingface for developing Transformers and making model sharing convenient. Multiple
parties including Certainly.io and Malte Hojmark-Bertelsen for making their models
publicly available. Alexandra Institute for developing and maintaining DaNLP which has
made it easy to get access to Danish resources and even supplied some of the tagged data
themselves.


.. toctree::
   :maxdepth: 2
   :hidden:

   installation
   using_dacy
   performance
   news
   faq

.. toctree::
   :maxdepth: 2
   :caption: Package References
   :hidden:

   dacy.download
   dacy.datasets
   dacy.score


.. toctree::
   :hidden:
   
   GitHub Repository <https://github.com/centre-for-humanities-computing/DaCy>

   
